@@ -15,7 +15,7 @@ class Config(gconf.Client):
         self.add_dir(base_path[0:-1], gconf.CLIENT_PRELOAD_RECURSIVE)
                 
     def notify_add(self, k, f):
-        gconf.Client.notify_add(self, self._base_path + k, f)
+        return gconf.Client.notify_add(self, self._base_path + k, f)
 
     def notify(self, k):
         gconf.Client.notify(self, self._base_path + k)
