@@ -117,11 +117,10 @@ class Library(GObject):
 
     def _update(self, folder):    
         # local connection, so we can run as thread
-        conn = sqlite3.connect(db_file)
-        cursor = conn.cursor()
+        con = sqlite3.connect(db_file)
 
         disc_files = self._get_files(folder)
-        db_files = cursor.execute("SELECT uri FROM songs").fetchall()
+        db_files = con.execute("SELECT uri FROM songs").fetchall()
         
         updated = len(disc_files) != len(db_files)
         
@@ -129,7 +128,7 @@ class Library(GObject):
             try:
                 disc_files.remove(str(uri))   # convert unicode
             except ValueError:
-                 cursor.execute("DELETE FROM songs WHERE uri = ?", (uri,))
+                 con.execute("DELETE FROM songs WHERE uri = ?", (uri,))
                  print "Removed: %s" % uri
 
         # add new files
@@ -183,30 +182,28 @@ class Library(GObject):
             mtime = os.path.getmtime(uri[7:].replace("%25", "%")) # strip file:// and unescape
             
             # store metadata in database (uri, title, artist, album, genre, tracknumber, date)
-            cursor.execute("INSERT INTO songs VALUES (?, ?, ?, ?, ?, ?, 0, datetime(?, 'unixepoch'))", \
+            con.execute("INSERT INTO songs VALUES (?, ?, ?, ?, ?, ?, 0, datetime(?, 'unixepoch'))", \
                 (uri, song["title"], song["artist"], song["album"], song["genre"], song["tracknumber"], mtime))
 
             print "Added: %s" % uri
                 
-        conn.commit()
-        conn.close()
+        con.commit()
+        con.close()
         self.emit("update-complete", updated)
 
 def check_db():
-    conn = sqlite3.connect(db_file)
-    c = conn.cursor()
-    
+    con = sqlite3.connect(db_file)
+  
     # the playcount column was introduced in v0.3.5
     try:
-        c.execute("SELECT playcount FROM songs LIMIT 1")
+        con.execute("SELECT playcount FROM songs LIMIT 1")
     except sqlite3.OperationalError:
-        c.execute("ALTER TABLE songs ADD COLUMN playcount INT")
+        con.execute("ALTER TABLE songs ADD COLUMN playcount INT")
 
 def setup_db():
-    conn = sqlite3.connect(db_file)
-    c = conn.cursor()
+    con = sqlite3.connect(db_file)
 
-    c.execute("CREATE TABLE songs (uri TEXT, title TEXT, artist TEXT, album TEXT, genre TEXT, tracknumber INT, playcount INT, date TEXT)")
+    con.execute("CREATE TABLE songs (uri TEXT, title TEXT, artist TEXT, album TEXT, genre TEXT, tracknumber INT, playcount INT, date TEXT)")
     #c.execute("CREATE TABLE playlists (name TEXT)")
 
-    conn.close()
+    con.close()
